"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.projectContainsGeneratorsOrExecutors = exports.findProjectsWithGeneratorsOrExecutors = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nrwl/devkit");
const path = require("path");
function default_1(host, schema) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const projects = yield findProjectsWithGeneratorsOrExecutors(host);
        projects.forEach((project) => {
            const generators = devkit_1.readJson(host, `${project.root}/generators.json`).generators;
            const executors = devkit_1.readJson(host, `${project.root}/executors.json`).executors;
            const projectFileName = devkit_1.names(project.name).fileName;
            devkit_1.generateFiles(host, path.join(__dirname, 'templates/index'), `docs`, {
                projectFileName,
                project,
                generators,
                executors,
            });
            Object.entries(generators).forEach(([generatorName, config]) => {
                const generatorFileName = devkit_1.names(generatorName).fileName;
                const schema = devkit_1.readJson(host, path.relative(process.cwd(), path.resolve(project.root, config.schema)));
                devkit_1.generateFiles(host, path.join(__dirname, 'templates/detail'), `docs/${projectFileName}/generators`, {
                    projectFileName,
                    project,
                    generatorName,
                    generatorFileName,
                    schema,
                });
            });
            Object.entries(generators).forEach(([generatorName, config]) => {
                const generatorFileName = devkit_1.names(generatorName).fileName;
                const schema = devkit_1.readJson(host, path.relative(process.cwd(), path.resolve(project.root, config.schema)));
                devkit_1.generateFiles(host, path.join(__dirname, 'templates/detail'), `docs/${projectFileName}/executors`, {
                    projectFileName,
                    project,
                    generatorName,
                    generatorFileName,
                    schema,
                });
            });
        });
    });
}
exports.default = default_1;
function findProjectsWithGeneratorsOrExecutors(host) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const projects = [];
        devkit_1.getProjects(host).forEach((configuration, project) => {
            const res = projectContainsGeneratorsOrExecutors(host, configuration);
            if (res) {
                projects.push(Object.assign(Object.assign(Object.assign({}, configuration), { name: project }), res));
            }
        });
        return projects;
    });
}
exports.findProjectsWithGeneratorsOrExecutors = findProjectsWithGeneratorsOrExecutors;
function projectContainsGeneratorsOrExecutors(host, project) {
    const executors = host.isFile(`${project.root}/executors.json`);
    const generators = host.isFile(`${project.root}/generators.json`);
    return !(executors || generators) ? false : { generators, executors };
}
exports.projectContainsGeneratorsOrExecutors = projectContainsGeneratorsOrExecutors;
//# sourceMappingURL=index.js.map